==> org.polarsys.kitalpha.ad.viewpoint.dsl.cs.text.diagram.source_1.2.2.201812041251.jar: org/polarsys/kitalpha/ad/viewpoint/dsl/cs/text/generator/SequencerDiagramTransientValue.java <==
/*******************************************************************************	
 * Copyright (c) 2014 Thales Global Services S.A.S.	
 * All rights reserved. This program and the accompanying materials	
 * are made available under the terms of the Eclipse Public License v1.0	
 * which accompanies this distribution, and is available at	
 * http://www.eclipse.org/legal/epl-v10.html	
 * 	
 * Contributors:	
 * Thales Global Services S.A.S - initial API and implementation	
 ******************************************************************************/
package org.polarsys.kitalpha.ad.viewpoint.dsl.cs.text.generator;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.xtext.serializer.sequencer.TransientValueService;
import org.polarsys.kitalpha.ad.viewpoint.dsl.as.model.vpdiagram.DiagramSet;
import org.polarsys.kitalpha.ad.viewpoint.dsl.as.model.vpdiagram.VpdiagramPackage;

/**
 * 
 * @author Faycal Abka
 *
 */
@SuppressWarnings("restriction")
public class SequencerDiagramTransientValue extends TransientValueService {

	
	@Override
	public ListTransient isListTransient(EObject semanticObject, EStructuralFeature feature) {
		if (semanticObject instanceof DiagramSet && (
				check_id(VpdiagramPackage.DIAGRAM_SET__ADDITIONAL_EXTERNAL_DATA, feature)
				|| check_id(VpdiagramPackage.DIAGRAM_SET__ADDITIONAL_EXTERNAL_GROUP, feature)))
			return ListTransient.YES;
		
		return super.isListTransient(semanticObject, feature);
	}
	
	
	private boolean check_id(int id, EStructuralFeature feature){
		return id == feature.getFeatureID();
	}
}

==> org.polarsys.kitalpha.ad.viewpoint.dsl.cs.text.diagram.source_1.3.2.202002101656.jar: org/polarsys/kitalpha/ad/viewpoint/dsl/cs/text/generator/SequencerDiagramTransientValue.java <==
/*******************************************************************************	
 * Copyright (c) 2014, 2018 Thales Global Services S.A.S.	
 * All rights reserved. This program and the accompanying materials	
 * are made available under the terms of the Eclipse Public License v1.0	
 * which accompanies this distribution, and is available at	
 * http://www.eclipse.org/legal/epl-v10.html	
 * 	
 * Contributors:	
 * Thales Global Services S.A.S - initial API and implementation	
 ******************************************************************************/
package org.polarsys.kitalpha.ad.viewpoint.dsl.cs.text.generator;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.xtext.serializer.sequencer.TransientValueService;
import org.polarsys.kitalpha.ad.viewpoint.dsl.as.model.vpdiagram.DiagramSet;
import org.polarsys.kitalpha.ad.viewpoint.dsl.as.model.vpdiagram.VpdiagramPackage;

/**
 * 
 * @author Faycal Abka
 *
 */
@SuppressWarnings("restriction")
public class SequencerDiagramTransientValue extends TransientValueService {

	
	@Override
	public ListTransient isListTransient(EObject semanticObject, EStructuralFeature feature) {
		if (semanticObject instanceof DiagramSet && (
				check_id(VpdiagramPackage.DIAGRAM_SET__ADDITIONAL_EXTERNAL_DATA, feature)
				|| check_id(VpdiagramPackage.DIAGRAM_SET__ADDITIONAL_EXTERNAL_GROUP, feature))) {
			return ListTransient.YES;
		}
		
		return super.isListTransient(semanticObject, feature);
	}
	
	
	private boolean check_id(int id, EStructuralFeature feature){
		return id == feature.getFeatureID();
	}
}
